class Sender:
    def __init__(self, sender_data):
        self.id = sender_data.get('id', '')
        self.name = sender_data.get('first_name', '')
        self.surname = sender_data.get('last_name', '')
        self.username = sender_data.get('username', '')
        self.language_code = sender_data.get('language_code', '')
        self.avatar = None

    def get_avatar(self, bot):
        if not self.avatar:
            params = {'user_id': self.id}
            response = bot.api.request('getUserProfilePhotos', params=params)
            if response['ok']:
                photos = response['result']['photos']
                if photos:
                    photo_file_id = photos[0][0]['file_id']
                    file_path = self.get_file_path(bot, photo_file_id)
                    self.avatar = file_path
        return self.avatar

    def get_file_path(self, bot, file_id):
        params = {'file_id': file_id}
        response = bot.api.request('getFile', params=params)
        if response['ok']:
            file_path = response['result']['file_path']
            return f"https://api.telegram.org/file/bot{bot.token}/{file_path}"
        return None

class Chat:
    def __init__(self, chat):
        self.id = chat.get('id', '')
        self.title = chat.get('title', '')
        self.link = f"t.me/{chat.get('username', '')}"
        self.is_forum = chat.get('is_forum', '')
        self.type = chat.get('type', '')

class Message:
    def __init__(self, message_data, bot):
        self.id = message_data['message_id']
        self.sender = Sender(message_data['from'])
        self.chat = Chat(message_data['chat'])
        self.date = message_data['date']
        self.text = message_data.get('text', '')
        self.bot = bot
        self.log = message_data

    def send(self, text, markup=False):
        params = {'chat_id': self.chat.id, 'text': text, 'parse_mode': 'Markdown' if markup else None}
        self.bot.api.request('sendMessage', params=params)

    def reply(self, text, markup=False):
        params = {'chat_id': self.chat.id, 'text': text, 'reply_to_message_id': self.id, 'parse_mode': 'Markdown' if markup else None}
        self.bot.api.request('sendMessage', params=params)
    
    def send_photo(self, photo, caption=None):
        params = {'chat_id': self.chat.id}
        files = {'photo': open(photo, 'rb')}  # Corrected the typo here
        if caption:
            params['caption'] = caption
        return self.bot.api.request('sendPhoto', params=params, files=files)


import requests

API_URL = "https://api.telegram.org/bot{token}/{method}"
FILE_URL = "https://api.telegram.org/file/bot{token}/{path}"

class API:
    def __init__(self, token):
        self.token = token
    
    def request(self, method, params=None, files=None):
        url = API_URL.format(token=self.token, method=method)
        response = requests.post(url, data=params, files=files)
        return response.json()



from setuptools import setup, find_packages

setup(
    name='monsgrams',
    version='1.2',
    description='A simple Python library for creating telegram bot.',
    author='grubx64',
    long_description=open("README.md").read(),
    long_description_content_type='text/markdown',
    license="MIT",
    url="https://github.com/tech-voyager/monsgrams/",
    packages=find_packages(),
    install_requires=[
        'aiohttp>=3.9.3'
    ],
)



import time
from base import Base

class Bot(Base):
    def __init__(self, token):
        super().__init__(token)
        self.last_update_id = None
        self.message_handlers = []

    def get_updates(self, offset=None, limit=None, timeout=None):
        params = {'offset': offset, 'limit': limit, 'timeout': timeout}
        response = self.api.request('getUpdates', params=params)
        if response['ok']:
            updates = response['result']
            if updates:
                self.last_update_id = updates[-1]['update_id'] + 1
            return updates
        else:
            return []

    def listen_message(self):
        while True:
            updates = self.get_updates(offset=self.last_update_id, timeout=30)
            for update in updates:
                if 'message' in update:
                    message_data = update['message']
                    message = Message(message_data, self)
                    self.handle_message(message)
            time.sleep(1)

    def event(self, func):
        self.message_handlers.append(func)
        return func

    def handle_message(self, message):
        for handler in self.message_handlers:
            handler(message)

from message import Message
